@@ -13,16 +13,11 @@
 #ifndef _REG_RESAMPLING_H
 #define _REG_RESAMPLING_H
 
-#ifdef RNIFTYREG
-#include "RNifti.h"
-#else
 #include "nifti1_io.h"
-#endif
-#include "_reg_tools.h"
 
-/** @brief This function resample a source image into the space of a target/result image.
- * The deformation is provided by a 4D nifti image which is in the space of the target image.
- * In the 4D image, for each voxel i,j,k, the position in the real word for the source image is store.
+/** @brief This function resample a floating image into the space of a reference/warped image.
+ * The deformation is provided by a 4D nifti image which is in the space of the reference image.
+ * In the 4D image, for each voxel i,j,k, the position in the real word for the floating image is store.
  * Interpolation can be nearest Neighbor (0), linear (1) or cubic spline (3).
  * The cubic spline interpolation assume a padding value of 0
  * The padding value for the NN and the LIN interpolation are user defined.
@@ -60,18 +55,19 @@ void reg_resampleImage_PSF(nifti_image *floatingImage,
 
 extern "C++"
 void reg_resampleGradient(nifti_image *gradientImage,
-                          nifti_image *warpedGradientImage,
+                          nifti_image *warImgGradient,
                           nifti_image *deformationField,
                           int interp,
                           float paddingValue);
 
 extern "C++"
 void reg_getImageGradient(nifti_image *floatingImage,
-                          nifti_image *warpedGradientImage,
+                          nifti_image *warImgGradient,
                           nifti_image *deformationField,
                           int *mask,
                           int interp,
                           float paddingValue,
+                          int active_timepoint,
                           bool *dti_timepoint = NULL,
                           mat33 *jacMat = NULL,
                           nifti_image *warpedImage = NULL);
